@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2011 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,36 +51,47 @@ package com.openexchange.report.client.container;
 
 public class ContextModuleAccessCombination {
 
-	private String userAccessCombination;
-	
-	private String userCount;
+    private String userAccessCombination;
 
-	public ContextModuleAccessCombination(String userAccessCombination,
-			String userCount) {
-		this.userAccessCombination = userAccessCombination;
-		this.userCount = userCount;
-	}
+    private String userCount;
 
-	public String getUserAccessCombination() {
-		return userAccessCombination;
-	}
+    private String inactiveCount;
 
-	public void setUserAccessCombination(String userAccessCombination) {
-		this.userAccessCombination = userAccessCombination;
-	}
+    public ContextModuleAccessCombination(final String userAccessCombination,
+        final String userCount, final String inactiveCount) {
+        this.userAccessCombination = userAccessCombination;
+        this.userCount = userCount;
+        this.inactiveCount = inactiveCount;
+    }
 
-	public String getUserCount() {
-		return userCount;
-	}
+    public String getUserAccessCombination() {
+        return userAccessCombination;
+    }
 
-	public void setUserCount(String userCount) {
-		this.userCount = userCount;
-	}
+    public void setUserAccessCombination(final String userAccessCombination) {
+        this.userAccessCombination = userAccessCombination;
+    }
+
+    public String getUserCount() {
+        return userCount;
+    }
+
+    public void setUserCount(final String userCount) {
+        this.userCount = userCount;
+    }
+
+    public String getInactiveCount() {
+        return inactiveCount;
+    }
+
+    public void setInactiveCount(final String inactiveCount) {
+        this.inactiveCount = inactiveCount;
+    }
+
+    @Override
+    public String toString() {
+        return "ContextModuleAccessCombinationObject [userAccessCombination="
+        + userAccessCombination + ", userCount=" + userCount + "]";
+    }
 
-	@Override
-	public String toString() {
-		return "ContextModuleAccessCombinationObject [userAccessCombination="
-				+ userAccessCombination + ", userCount=" + userCount + "]";
-	}
-	
 }
