@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2011 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,34 +51,34 @@ package com.openexchange.report.client.container;
 
 public class Total {
 
-	private String contexts;
-	
-	private String users;
-	
-	public Total(String contexts, String users) {
-		this.contexts = contexts;
-		this.users = users;
-	}
+    private String contexts;
 
-	public String getContexts() {
-		return contexts;
-	}
+    private String users;
 
-	public void setContexts(String contexts) {
-		this.contexts = contexts;
-	}
+    public Total(final String contexts, final String users) {
+        this.contexts = contexts;
+        this.users = users;
+    }
 
-	public String getUsers() {
-		return users;
-	}
+    public String getContexts() {
+        return contexts;
+    }
 
-	public void setUsers(String users) {
-		this.users = users;
-	}
+    public void setContexts(final String contexts) {
+        this.contexts = contexts;
+    }
+
+    public String getUsers() {
+        return users;
+    }
+
+    public void setUsers(final String users) {
+        this.users = users;
+    }
+
+    @Override
+    public String toString() {
+        return "TotalObject [contexts=" + contexts + ", users=" + users + "]";
+    }
 
-	@Override
-	public String toString() {
-		return "TotalObject [contexts=" + contexts + ", users=" + users + "]";
-	}
-	
 }
