@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2011 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import java.util.jar.Manifest;
 public class VersionHandler {
 
     public static String[] getServerVersion() throws IOException {
-    	String[] retval = new String[2];
+        final String[] retval = new String[2];
 
         URL manifestURL = new URL("jar:file:/opt/open-xchange/bundles/com.openexchange.admin.jar!/META-INF/MANIFEST.MF");
         Attributes attrs = new Manifest(manifestURL.openStream()).getMainAttributes();
@@ -66,7 +66,7 @@ public class VersionHandler {
         manifestURL = new URL("jar:file:/opt/open-xchange/bundles/com.openexchange.server.jar!/META-INF/MANIFEST.MF");
         attrs = new Manifest(manifestURL.openStream()).getMainAttributes();
         retval[1] = attrs.getValue("OXVersion") + " Rev" + attrs.getValue("OXRevision");
-        
+
         return retval;
     }
 
